@@ -23,23 +23,25 @@
 /*
  * Constants
  */
-const HEADERINFO_CONTRACTID = "@mozilla.org/js_headerinfo;1";
-const HEADERINFO_CID = Components.ID('{d5598f0d-5eba-43bc-b8e1-342a23bce3ea}');
-const CATMAN_CONTRACTID = "@mozilla.org/categorymanager;1";
-const JS_SCRIPTABLEINPUTSTREAM_CID = "@mozilla.org/scriptableinputstream;1";
-const JS_SCRIPTABLEINPUTSTREAM     = "nsIScriptableInputStream";
-const JS_ScriptableInputStream = new Components.Constructor
-         ( JS_SCRIPTABLEINPUTSTREAM_CID, JS_SCRIPTABLEINPUTSTREAM );
-  
+if(!livehttpheaders) var livehttpheaders={};
+if(!livehttpheaders.nshi) livehttpheaders.nshi={};
+
+livehttpheaders.nshi.HEADERINFO_CONTRACTID = "@mozilla.org/js_headerinfo;1";
+livehttpheaders.nshi.HEADERINFO_CID = Components.ID('{d5598f0d-5eba-43bc-b8e1-342a23bce3ea}');
+livehttpheaders.nshi.CATMAN_CONTRACTID = "@mozilla.org/categorymanager;1";
+livehttpheaders.nshi.JS_SCRIPTABLEINPUTSTREAM_CID = "@mozilla.org/scriptableinputstream;1";
+livehttpheaders.nshi.JS_SCRIPTABLEINPUTSTREAM     = "nsIScriptableInputStream";
+livehttpheaders.nshi.JS_ScriptableInputStream = new Components.Constructor
+         ( livehttpheaders.nshi.JS_SCRIPTABLEINPUTSTREAM_CID, livehttpheaders.nshi.JS_SCRIPTABLEINPUTSTREAM );
 
 /*
  * Utility functions 
  */
-function dtb(v,d) {
+livehttpheaders.nshi.dtb = function (v,d) {
   var tmp = ("00000000000000000000000000000000"+Math.round(v).toString(2)).slice(-d);
   return tmp.match(/......../g).join(" ");
 }
-function dth(v,d) {
+livehttpheaders.nshi.dth = function (v,d) {
   return ("000000000000"+Math.round(v).toString(16)).slice(-d);
 }
 
@@ -48,8 +50,8 @@ function dth(v,d) {
  * Class definitions
  */
 
-var flag = 1;
-var nsHeaderInfo = {
+livehttpheaders.nshi.flag = 1;
+livehttpheaders.nshi.nsHeaderInfo = {
   onStateChange: function(aProg, aRequest, aFlags, aStatus)
   {
     //dump("onStateChange\n");
@@ -69,13 +71,13 @@ var nsHeaderInfo = {
           aRequest = aRequest.baseChannel.QueryInterface(Components.interfaces.nsIHttpChannel);
         }
 
-        aProg.DOMWindow._liveHttpHeaders = new HeaderInfoVisitor(aRequest).getHeaders();
-        if (flag) {
+        aProg.DOMWindow.document._liveHttpHeaders = new livehttpheaders.nshi.HeaderInfoVisitor(aRequest).getHeaders();
+        if (livehttpheaders.nshi.flag) {
           try {
-            var controller = new FakeController(new HeaderInfoVisitor(aRequest).getHeaders());
+            var controller = new livehttpheaders.nshi.FakeController(new livehttpheaders.nshi.HeaderInfoVisitor(aRequest).getHeaders());
             controller.install(aProg.DOMWindow);
           } catch (ex) {
-            flag = 0;
+            livehttpheaders.nshi.flag = 0;
           }
         }
 
@@ -133,12 +135,12 @@ var nsHeaderInfo = {
         if ('nsINetModuleMgr' in Components.interfaces) {
 	    // Should be an old version of Mozilla (before september 15, 2003
           var netModuleMgr = Components.classes["@mozilla.org/network/net-extern-mod;1"].getService(Components.interfaces.nsINetModuleMgr);
-          netModuleMgr.registerModule("@mozilla.org/network/moduleMgr/http/request;1", nsHeaderInfo);
+          netModuleMgr.registerModule("@mozilla.org/network/moduleMgr/http/request;1", livehttpheaders.nshi.nsHeaderInfo);
           //netModuleMgr.registerModule("@mozilla.org/network/moduleMgr/http/response;1", nsHeaderInfo);
 	    } else {
 	      // Should be a new version of  Mozilla (after september 15, 2003)
           var observerService = Components.classes["@mozilla.org/observer-service;1"].getService(Components.interfaces.nsIObserverService);
-          observerService.addObserver(nsHeaderInfo, "http-on-modify-request", false);
+          observerService.addObserver(livehttpheaders.nshi.nsHeaderInfo, "http-on-modify-request", false);
           //observerService.addObserver(nsHeaderInfo, "http-on-examine-response", false);
 	}
         
@@ -169,7 +171,7 @@ var nsHeaderInfo = {
     }
 };
 
-function HeaderInfoVisitor (oHttp)
+livehttpheaders.nshi.HeaderInfoVisitor = function(oHttp)
 {
   // Keep the Http request object
   this.oHttp = oHttp;
@@ -187,7 +189,7 @@ function HeaderInfoVisitor (oHttp)
   this.visitRequest(this);
   this.visitResponse(this);
 }
-HeaderInfoVisitor.prototype =
+livehttpheaders.nshi.HeaderInfoVisitor.prototype =
 {
   oHttp : null,
   headers : null,
@@ -250,16 +252,17 @@ HeaderInfoVisitor.prototype =
       var pps = Components.classes["@mozilla.org/network/protocol-proxy-service;1"].getService().QueryInterface(Components.interfaces.nsIProtocolProxyService);
 
       // If a proxy is used for this url, we need to keep the host part
-      if (pps.proxyEnabled && (pps.examineForProxy(uri)!=null)) {
-        // Proxies are enabled.  Now, check if it is an HTTP proxy.
-        var pref = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefService);
-        pref = pref.getBranch("");
-        // Now, get the value of the HTTP proxy fields
-        var http_host = pref.getCharPref("network.proxy.http");
-        var http_port = pref.getIntPref("network.proxy.http_port");
-        // network.proxy.http_port network.proxy.http
-        if (http_host && http_port>0) {
-          return true; // HTTP Proxy
+      if (typeof(pps.proxyEnabled) != "undefined") {
+        // Mozilla up to 1.7
+        if (pps.proxyEnabled && (pps.examineForProxy(uri)!=null)) {
+          // Proxies are enabled.  Now, check if it is an HTTP proxy.
+          return this.isHttpProxy();
+        }
+      } else {
+        // Firefox and Mozilla 1.8+
+        if (pps.resolve(uri, pps.RESOLVE_NON_BLOCKING)!=null) {
+          // Proxies are enabled.  Now, check if it is an HTTP proxy.
+          return this.isHttpProxy();
         }
       }
       return false; // No proxy or not HTTP Proxy
@@ -268,6 +271,21 @@ HeaderInfoVisitor.prototype =
     }
   },
 
+  isHttpProxy : function() 
+  {
+    // Check if an HTTP proxy is configured.
+    var pref = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefService);
+    pref = pref.getBranch("");
+    // Now, get the value of the HTTP proxy fields
+    var http_host = pref.getCharPref("network.proxy.http");
+    var http_port = pref.getIntPref("network.proxy.http_port");
+    // network.proxy.http_port network.proxy.http
+    if (http_host && http_port>0) {
+      return true; // HTTP Proxy
+    }
+    return false;
+  },
+
   readLine : function(stream) {
     var line = "";
     var size = 0;
@@ -298,7 +316,7 @@ HeaderInfoVisitor.prototype =
           this.oHttp.uploadStream.seek(0,0);
  
           // Need to create a seekable stream to be able to read the stream in javascript
-          var stream = new JS_ScriptableInputStream();
+          var stream = new livehttpheaders.nshi.JS_ScriptableInputStream();
           stream.init(this.oHttp.uploadStream);
 
           // Now we can start to get the headers
@@ -308,16 +326,23 @@ HeaderInfoVisitor.prototype =
             visitor.visitHeader(tmp[0],tmp[1]);
             line = this.readLine(stream);
           }
-        } catch (ex) {}
-        // The main request should take care of closing the stream,
-        // not this listener
+        } catch (ex) {
+        } finally {
+            // The main request should take care of closing the stream,
+            // not this listener.  But this seems to cause problems with
+            // Seamonkey!
+            //this.oHttp.uploadStream.close();
+            //stream.close();
+            //this.oHttp.uploadStream.seek(2,0);
+            try { stream.read(stream.available()); } catch (ex) {}
+        }
       }
     } catch (e) {}
   },
 
   visitHeader : function (name, value)
   {
-    this.theaders[name] = value + "\u65E5\u672C\u8A9E";
+    this.theaders[name] = value;
   },
   visitRequest : function ()
   {
@@ -365,12 +390,12 @@ HeaderInfoVisitor.prototype =
   }
 }
 
-function FakeController(oHeaders)
+livehttpheaders.nshi.FakeController = function(oHeaders)
 {
   this.headers = oHeaders;
   this.wrappedJSObject = this;
 }
-FakeController.prototype = {
+livehttpheaders.nshi.FakeController.prototype = {
   headers: null,
   url: null,
   isCommandEnabled: function(command)
@@ -402,7 +427,7 @@ FakeController.prototype = {
  */
 
 /* nsHeaderInfo Module (for XPCOM registration) */
-var nsHeaderInfoModule = {
+livehttpheaders.nshi.nsHeaderInfoModule = {
     firstTime : true,
     registerSelf: function(compMgr, fileSpec, location, type) {
       dump("nsHeaderInfo: registerSelf called!\n");
@@ -411,40 +436,40 @@ var nsHeaderInfoModule = {
         throw Components.results.NS_ERROR_FACTORY_REGISTER_AGAIN;
       }
       var compMgr = compMgr.QueryInterface(Components.interfaces.nsIComponentRegistrar);
-      compMgr.registerFactoryLocation(HEADERINFO_CID, 
+      compMgr.registerFactoryLocation(livehttpheaders.nshi.HEADERINFO_CID, 
                                       "nsHeaderInfo JS component", 
-                                      HEADERINFO_CONTRACTID, 
+                                      livehttpheaders.nshi.HEADERINFO_CONTRACTID, 
                                       fileSpec, location, type);
 
-      var catman = Components.classes[CATMAN_CONTRACTID].getService(Components.interfaces.nsICategoryManager);
+      var catman = Components.classes[livehttpheaders.nshi.CATMAN_CONTRACTID].getService(Components.interfaces.nsICategoryManager);
       catman.addCategoryEntry("app-startup", "HeaderInfo",
-                              HEADERINFO_CONTRACTID,true, true);
+                              livehttpheaders.nshi.HEADERINFO_CONTRACTID,true, true);
     },
 
     unregisterSelf: function(compMgr, fileSpec, location) {
       // Remove the auto-startup
       var compMgr = compMgr.QueryInterface(Components.interfaces.nsIComponentRegistrar);
 
-      compMgr.unregisterFactoryLocation(HEADERINFO_CID, fileSpec);
-      var catman = Components.classes[CATMAN_CONTRACTID].getService(Components.interfaces.nsICategoryManager);
-      catman.deleteCategoryEntry("app-startup", HEADERINFO_CONTRACTID, true);
+      compMgr.unregisterFactoryLocation(livehttpheaders.nshi.HEADERINFO_CID, fileSpec);
+      var catman = Components.classes[livehttpheaders.nshi.CATMAN_CONTRACTID].getService(Components.interfaces.nsICategoryManager);
+      catman.deleteCategoryEntry("app-startup", livehttpheaders.nshi.HEADERINFO_CONTRACTID, true);
     },
 
     getClassObject: function(compMgr, cid, iid) {
-        if (!cid.equals(HEADERINFO_CID))
+        if (!cid.equals(livehttpheaders.nshi.HEADERINFO_CID))
             throw Components.results.NS_ERROR_NO_INTERFACE;
 
         if (!iid.equals(Components.interfaces.nsIFactory))
             throw Components.results.NS_ERROR_NOT_IMPLEMENTED;
 
-        return nsHeaderInfoFactory;
+        return livehttpheaders.nshi.nsHeaderInfoFactory;
     },
 
     canUnload: function(compMgr) { return true; }
 };
 
 /* nsHeaderInfo Class Factory */
-var nsHeaderInfoFactory = {
+livehttpheaders.nshi.nsHeaderInfoFactory = {
     createInstance: function(outer, iid) {
         if (outer != null) {
             throw Components.results.NS_ERROR_NO_AGGREGATION;
@@ -454,7 +479,7 @@ var nsHeaderInfoFactory = {
             !iid.equals(Components.interfaces.nsIObserver)) {
             throw Components.results.NS_ERROR_INVALID_ARG;
         }
-        return nsHeaderInfo;
+        return livehttpheaders.nshi.nsHeaderInfo;
     }
 }
 
@@ -463,5 +488,5 @@ var nsHeaderInfoFactory = {
  */
 
 /* module initialisation */
-function NSGetModule(comMgr, fileSpec) { return nsHeaderInfoModule; }
+function NSGetModule(comMgr, fileSpec) { return livehttpheaders.nshi.nsHeaderInfoModule; }
 
