@@ -1,7 +1,7 @@
 const X_MSG = 	   "Install Live HTTP Header";
 const X_NAME =     "/livehttpheaders";
 const X_NAME_COM = "/livehttpheaders_com";
-const X_VER  =     "0.15";
+const X_VER  =     "0.16";
 const X_JAR_FILE = "livehttpheaders.jar";
 const X_COM_FILE = "nsHeaderInfo.js";
 
@@ -26,6 +26,7 @@ if (confirm("Do you wish to install LiveHTTPHeaders to your profile ?\n\n"+
 }
 var componentDir = getFolder("Components");
 var iconFolder = getFolder(getFolder("Chrome", "icons"), "default");
+var prefFolder = getFolder(getFolder("Program", "defaults"), "pref");
 
 addFile(X_NAME, "chrome/" + X_JAR_FILE, chromeFolder, "");
 // It's okay if this fails; the component and icons aren't critical to the
@@ -33,8 +34,9 @@ addFile(X_NAME, "chrome/" + X_JAR_FILE, chromeFolder, "");
 err = getLastError();
 if (err == SUCCESS || err == REBOOT_NEEDED) {
   addFile(X_NAME_COM, "components/" + X_COM_FILE, componentDir, "");
-  addFile(X_NAME, "icons/default/LiveHTTPHeaders.xpm", iconFolder, "");
-  addFile(X_NAME, "icons/default/LiveHTTPHeaders.ico", iconFolder, "");
+  addFile(X_NAME, "chrome/icons/default/LiveHTTPHeaders.xpm", iconFolder, "");
+  addFile(X_NAME, "chrome/icons/default/LiveHTTPHeaders.ico", iconFolder, "");
+  addFile(X_NAME, "defaults/preferences/prefs.js", prefFolder, "livehttpheaders.js");
   resetError();
 }
 
